//
//  Gauge.swift
//  Gauge_Demo
//
//  Created by Pascal PISZYNA on 12/01/2017.
//  Copyright © 2017 Pascal PISZYNA. All rights reserved.
//

import UIKit

@IBDesignable class Gauge: UIView {

    let π = CGFloat(M_PI)
    @IBInspectable var value:Int = 50 {
        didSet {
            //print("Nouvelle valeur : \(value)")
            setNeedsDisplay()
        }
    }
    @IBInspectable var max:Int = 100
    @IBInspectable var gaugeColor:UIColor = UIColor.red
    @IBInspectable var units:String = ""
    @IBInspectable var title:String = ""
    
    let valueLabel = UILabel()
    let titleLabel = UILabel()
    
    override func draw(_ rect: CGRect) {
        // Drawing code
        let w = bounds.width
        let h = bounds.height
        let r:CGFloat = min(w,h)
        let center = CGPoint(x:w/2, y:h/2)
        let arcWidth: CGFloat = 10
        let startAngle: CGFloat = 3 * π / 4
        let endAngle: CGFloat = π / 4
        let backColor = gaugeColor.withAlphaComponent(0.2)
        
        // Dessin du fond de la jauge
        let path = UIBezierPath(arcCenter: center,
                                radius: r/2 - arcWidth/2,
                                startAngle: startAngle,
                                endAngle: endAngle,
                                clockwise: true)
        path.lineWidth = arcWidth
        backColor.setStroke()
        path.stroke()
        // Dessin de la jauge
        let angleDifference:CGFloat = 2 * π - startAngle + endAngle
        let arcLength = angleDifference / CGFloat(max)
        let stopAngle = arcLength * CGFloat(value) + startAngle
        
        let gaugePath = UIBezierPath(arcCenter: center,
                                radius: r/2 - arcWidth + arcWidth / 8,
                                startAngle: startAngle,
                                endAngle: stopAngle,
                                clockwise: true)
        
        gaugePath.addArc(withCenter: center,
                         radius: r/2 - arcWidth / 8,
                         startAngle: stopAngle,
                         endAngle: startAngle,
                         clockwise: false)

        gaugePath.lineWidth = arcWidth / 4
        gaugeColor.setStroke()
        gaugePath.close()
        gaugePath.stroke()
        
        // Affichage de la valeur
        valueLabel.frame = CGRect(x: 0, y: h/2 - h/16, width: w, height: h/8)
        valueLabel.text = String(value) + units
        valueLabel.textAlignment = .center
        valueLabel.font = valueLabel.font.withSize(h/8)
        self.addSubview(valueLabel)
        
        // Affichage du titre
        titleLabel.frame = CGRect(x: 0, y: h - h/10, width: w, height: h/10)
        titleLabel.text = title
        titleLabel.textAlignment = .center
        titleLabel.font = valueLabel.font.withSize(h/10)
        self.addSubview(titleLabel)
    }
}
